@@ -11,6 +11,10 @@
 #include <stdlib.h>
 #include <selinux/selinux.h>
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
 
 /*
  * SID format and operations
@@ -162,10 +166,10 @@ struct avc_lock_callback {
  * structures above).
  */
 int avc_init(const char *msgprefix,
-	     struct avc_memory_callback *mem_callbacks,
-	     struct avc_log_callback *log_callbacks,
-	     struct avc_thread_callback *thread_callbacks,
-	     struct avc_lock_callback *lock_callbacks);
+	     const struct avc_memory_callback *mem_callbacks,
+	     const struct avc_log_callback *log_callbacks,
+	     const struct avc_thread_callback *thread_callbacks,
+	     const struct avc_lock_callback *lock_callbacks);
 
 /**
  * avc_cleanup - Remove unused SIDs and AVC entries.
@@ -362,4 +366,8 @@ void avc_av_stats(void);
  */
 void avc_sid_stats(void);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _SELINUX_AVC_H_ */
