@@ -3,6 +3,11 @@
 
 #include <selinux/selinux.h>
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 #define SELINUX_DEFAULTUSER "user_u"
 
 /* Get an ordered list of authorized security contexts for a user session
@@ -49,4 +54,8 @@ extern int query_user_context(security_context_t *list,
 extern int manual_user_enter_context(const char *user,
 				     security_context_t *newcon);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
