@@ -5,6 +5,11 @@
 #ifndef _SELINUX_GET_DEFAULT_TYPE_H_
 #define _SELINUX_GET_DEFAULT_TYPE_H_
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /* Return path to default type file. */
 const char *selinux_default_type_path(void);
 
@@ -13,4 +18,8 @@ const char *selinux_default_type_path(void);
    Return 0 on success or -1 otherwise. */
 int get_default_type (const char* role, char** type);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif  /* ifndef _GET_DEFAULT_TYPE_H_ */
