@@ -378,7 +378,8 @@ hidden_def(avc_av_stats)
 static inline struct avc_node *avc_reclaim_node(void)
 {
   struct avc_node *prev, *cur;
-  int hvalue, try;
+  int try;
+  u_int32_t hvalue;
 
   hvalue = avc_cache.lru_hint;
   for (try = 0; try < 2; try++) {
@@ -770,8 +771,8 @@ static inline int check_avc_ratelimit(void)
 static void avc_dump_av(security_class_t tclass, access_vector_t av)
 {
   const u16 *common_pts_idx = 0;
-  u_int32_t common_base = 0;
-  int i, i2, perm;
+  u_int32_t common_base = 0, perm;
+  unsigned int i, i2;
 
   if (av == 0) {
     log_append(avc_audit_buf, " null");
@@ -790,9 +791,11 @@ static void avc_dump_av(security_class_t tclass, access_vector_t av)
   i = 0;
   perm = 1;
   while (perm < common_base) {
-    if (perm & av)
+    if (perm & av) {
       log_append(avc_audit_buf, " %s",
                  common_perm_to_string_data.str + common_pts_idx[i]);
+      av &= ~perm;
+    }
     i++;
     perm <<= 1;
   }
@@ -804,13 +807,17 @@ static void avc_dump_av(security_class_t tclass, access_vector_t av)
 	    (av_perm_to_string[i2].value == perm))
 	  break;
       }
-      if (i2 < ARRAY_SIZE(av_perm_to_string))
+      if (i2 < ARRAY_SIZE(av_perm_to_string)) {
 	log_append(avc_audit_buf, " %s",
                    av_perm_to_string_data.str + av_perm_to_string[i2].nameidx);
+	av &= ~perm;
+      }
     }
     i++;
     perm <<= 1;
   }
+  if (av)
+    log_append(avc_audit_buf, " 0x%x", av);
   log_append(avc_audit_buf, " }");
 }
 
@@ -960,7 +967,7 @@ int avc_has_perm(security_id_t ssid, security_id_t tsid,
 		 security_class_t tclass, access_vector_t requested,
                  struct avc_entry_ref *aeref, void *auditdata)
 {
-  struct av_decision avd = {0};
+  struct av_decision avd = {0,0,0,0,0};
   int rc;
 
   rc = avc_has_perm_noaudit(ssid, tsid, tclass, requested, aeref, &avd);
@@ -990,6 +997,7 @@ int avc_add_callback(int (*callback)(u_int32_t event, security_id_t ssid,
   c->events = events;
   c->ssid = ssid;
   c->tsid = tsid;
+  c->tclass = tclass;
   c->perms = perms;
   c->next = avc_callbacks;
   avc_callbacks = c;
