@@ -125,7 +125,7 @@ int avc_netlink_check_nb(void) {
 		
     nlh = (struct nlmsghdr *)buf;
 		
-    if (nlh->nlmsg_flags & MSG_TRUNC || nlh->nlmsg_len > rc) {
+    if (nlh->nlmsg_flags & MSG_TRUNC || nlh->nlmsg_len > (unsigned)rc) {
       avc_log("%s:  warning: incomplete netlink message\n", avc_prefix);
       goto out;
     }
@@ -212,7 +212,7 @@ void avc_netlink_loop(void) {
 		
     nlh = (struct nlmsghdr *)buf;
 		
-    if (nlh->nlmsg_flags & MSG_TRUNC || nlh->nlmsg_len > ret) {
+    if (nlh->nlmsg_flags & MSG_TRUNC || nlh->nlmsg_len > (unsigned) ret) {
       avc_log("%s:  netlink thread: incomplete netlink message\n", avc_prefix);
       goto out;
     }
