@@ -20,7 +20,7 @@ static inline unsigned sidtab_hash(security_context_t key) {
 	val = 0;
 	keyp = (char*)key;
 	size = strlen(keyp);
-	for (p = keyp; (p - keyp) < size; p++)
+	for (p = keyp; (unsigned int)(p - keyp) < size; p++)
 		val = (val << 4 | (val >> (8*sizeof(unsigned int)-4))) ^ (*p);
 	return val & (SIDTAB_SIZE - 1);
 }
