@@ -5,7 +5,7 @@
 #include <errno.h>
 #include <string.h>
 #include <stdio.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include "policy.h"
 #include <limits.h>
 
@@ -25,3 +25,4 @@ int security_check_context(security_context_t con)
 		return -1;
 	return 0;
 }
+hidden_def(security_check_context)
