@@ -6,7 +6,7 @@
 #include <errno.h>
 #include <string.h>
 #include <asm/page.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include "policy.h"
 #include <limits.h>
 
@@ -58,3 +58,4 @@ out:
 	close(fd);
 	return ret;
 }
+hidden_def(security_compute_av)
