@@ -1,7 +1,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include <stdlib.h>
 #include <errno.h>
 #include <limits.h>
@@ -53,6 +53,7 @@ out:
 	close(fd);
 	return enabled;
 }
+hidden_def(is_selinux_enabled)
 
 /*
  * Function: is_selinux_mls_enabled()
@@ -81,3 +82,4 @@ int is_selinux_mls_enabled(void)
 
 	return enabled;
 }
+hidden_def(is_selinux_mls_enabled)
