@@ -1,5 +1,5 @@
 #include <unistd.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include <stdlib.h>
 #include <errno.h>
 
@@ -7,3 +7,4 @@ void freecon(security_context_t con)
 {
 	free(con);
 }
+hidden_def(freecon)
