@@ -6,7 +6,7 @@
 #include <ctype.h>
 #include <pwd.h>
 #include "selinux_internal.h"
-#include <selinux/context.h>
+#include "context_internal.h"
 #include "get_context_list_internal.h"
 
 #define USERPRIORITY 1
