@@ -1,7 +1,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include <stdlib.h>
 #include <errno.h>
 #include <asm/page.h>
@@ -42,3 +42,4 @@ out:
 	close(fd);
 	return ret;
 }
+hidden_def(getcon)
