@@ -4,7 +4,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include "policy.h"
 #include <stdio.h>
 #include <limits.h>
@@ -31,3 +31,4 @@ int security_getenforce(void)
 
 	return enforce;
 }
+hidden_def(security_getenforce)
