@@ -1,7 +1,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include <stdlib.h>
 #include <errno.h>
 #include <sys/xattr.h>
@@ -43,3 +43,4 @@ out:
 		*context = buf;
 	return ret;
 }
+hidden_def(getfilecon)
