@@ -8,6 +8,8 @@
 #include <asm/page.h>
 #include <stdio.h>
 
+#include "policy.h"
+
 char *selinux_mnt = NULL;
 
 static void init_selinuxmnt(void) __attribute__ ((constructor));
@@ -32,7 +34,7 @@ static void init_selinuxmnt(void)
 		
 	memset(buf, 0, size);
 
-	while(( bufp = fgets(buf, size, fp)))
+	while(( bufp = fgets_unlocked(buf, size, fp)))
 	{
 		char *tmp;
 		p = strchr(buf, ' ');
@@ -60,4 +62,9 @@ out:
 	return;
 
 }
+
+void set_selinuxmnt(char *mnt)
+{
+	selinux_mnt = mnt;
+}
  
