@@ -23,7 +23,8 @@ static int context_menu (security_context_t *list)
     {
         printf ("Enter number of choice: ");
         fflush (stdin);
-        fgets (response, sizeof (response), stdin);
+        if (fgets (response, sizeof (response), stdin) == NULL)
+		continue;
         fflush (stdin);
         choice = strtol (response, NULL, 10);
     }
@@ -50,7 +51,8 @@ int query_user_context (security_context_t *list,
     if (list[1]) {
             printf ("Do you want to choose a different one? [n]");
             fflush (stdin);
-            fgets (response, sizeof (response), stdin);
+            if (fgets (response, sizeof (response), stdin) == NULL)
+		return -1;
             fflush (stdin);
 
             if ((response[0] == 'y') || (response[0] == 'Y'))
@@ -86,9 +88,11 @@ static void get_field (const char* fieldstr, char* newfield, int newfieldlen)
     {
         printf ("\tEnter %s ", fieldstr);
         fflush (stdin);
-        fgets (newfield, newfieldlen, stdin);
+        if (fgets (newfield, newfieldlen, stdin) == NULL)
+	    continue;
         fflush (stdin);
-        newfield[strlen(newfield)-1] = '\0';
+	if (newfield[strlen(newfield)-1] == '\n')
+	    newfield[strlen(newfield)-1] = '\0';
  
         if (strlen(newfield) == 0)  
         {
@@ -137,9 +141,11 @@ int manual_user_enter_context (const char *user, security_context_t *newcon)
     while (!done)
     {
         printf ("Would you like to enter a security context? [y]");
-        fgets (response, sizeof(response), stdin);
-        if ((response[0] == 'n') || (response[0] == 'N'))
+        if (fgets (response, sizeof(response), stdin) == NULL
+            || (response[0] == 'n') || (response[0] == 'N')) {
+            context_free(new_context);
             return -1;
+	}
  
         /* Allow the user to enter each field of the context individually */
         if (context_user_set (new_context, user))
