@@ -1,11 +1,11 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
-#include <selinux/selinux.h>
 #include <selinux/flask.h>
-#include <selinux/context.h>
+#include "selinux_internal.h"
+#include "context_internal.h"
 
-int rpm_execcon(unsigned int verified, 
+int rpm_execcon(unsigned int verified __attribute__((unused)), 
 		const char *filename, 
 		char *const argv[], char *const envp[])
 {
@@ -13,6 +13,9 @@ int rpm_execcon(unsigned int verified,
 	context_t con = NULL;
 	int rc;
 
+	if (is_selinux_enabled() < 1)
+		return execve(filename, argv, envp);
+
 	rc = getcon(&mycon);
 	if (rc < 0)
 		goto out;
