@@ -26,7 +26,9 @@
 #define BOOLEANS          7
 #define MEDIA_CONTEXTS    8
 #define REMOVABLE_CONTEXT 9
-#define NEL               10
+#define CUSTOMIZABLE_TYPES    10
+#define USERS_DIR         11
+#define NEL               12
 
 /* New layout is relative to SELINUXDIR/policytype. */
 static char *file_paths[NEL];
@@ -210,6 +212,12 @@ hidden_def(selinux_file_context_path)
 const char *selinux_media_context_path() {
   return get_path(MEDIA_CONTEXTS);
 }
+hidden_def(selinux_media_context_path)
+
+const char *selinux_customizable_types_path() {
+  return get_path(CUSTOMIZABLE_TYPES);
+}
+hidden_def(selinux_customizable_types_path)
 
 const char *selinux_contexts_path() {
   return get_path(CONTEXTS_DIR);
@@ -225,3 +233,8 @@ const char *selinux_booleans_path() {
 }
 hidden_def(selinux_booleans_path)
 
+const char *selinux_users_path() {
+  return get_path(USERS_DIR);
+}
+hidden_def(selinux_users_path)
+
