@@ -6,6 +6,7 @@ hidden_proto(security_commit_booleans)
 hidden_proto(security_check_context)
 hidden_proto(security_compute_av)
 hidden_proto(security_compute_user)
+hidden_proto(security_compute_create)
 hidden_proto(is_selinux_enabled)
 hidden_proto(is_selinux_mls_enabled)
 hidden_proto(security_check_context)
@@ -13,6 +14,8 @@ hidden_proto(freecon)
 hidden_proto(freeconary)
 hidden_proto(getprevcon)
 hidden_proto(getcon)
+hidden_proto(getfilecon)
+hidden_proto(setexeccon)
 hidden_proto(security_getenforce)
 hidden_proto(selinux_default_context_path)
 hidden_proto(selinux_failsafe_context_path)
@@ -20,3 +23,7 @@ hidden_proto(selinux_removable_context_path)
 hidden_proto(selinux_file_context_path)
 hidden_proto(selinux_user_contexts_path)
 hidden_proto(selinux_booleans_path)
+hidden_proto(selinux_customizable_types_path)
+hidden_proto(selinux_media_context_path)
+hidden_proto(matchpathcon_init)
+hidden_proto(selinux_users_path)
