@@ -1,7 +1,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 
 int setexeccon(security_context_t context)
 {
@@ -21,3 +21,4 @@ int setexeccon(security_context_t context)
 	else
 		return 0;
 }
+hidden_def(setexeccon)
