@@ -10,17 +10,17 @@ int main(int argc, char **argv)
 
 	if (argc < 2) {
 		fprintf(stderr, "usage:  %s path...\n", argv[0]);
-		exit(1);
+		return 1;
 	}
 
 	for (i = 1; i < argc; i++) {
 		rc = matchpathcon(argv[i], 0, &buf);
 		if (rc < 0) {
 			fprintf(stderr, "%s:  matchpathcon(%s) failed\n", argv[0], argv[i]);
-			exit(2);
+			return 2;
 		}
 		printf("%s\t%s\n", argv[i], buf);
 		freecon(buf);
 	}
-	exit(0);
+	return 0;
 }
